# [1.8.9](https://github.com/seriaati/ambr/compare/v1.8.8..v1.8.9) - 2025-10-25

## Bug Fixes

- Prevent closing custom session - ([2e1ebc1](https://github.com/seriaati/ambr/commit/2e1ebc121fd30b8a18d8f28803b8e289d53a8acf))
- Correct command for deploying documentation - ([d1027b8](https://github.com/seriaati/ambr/commit/d1027b810b0f4ac68dcc73f6fa8d20b0da8e848e))

## Continuous Integrations

- **(Mergify)** configuration update (#130) - ([bc1bd0a](https://github.com/seriaati/ambr/commit/bc1bd0a4a45f63286b770c5f60da1c7a1ed666b4))
- Move ruff lint to pre commit ci - ([b1c05b0](https://github.com/seriaati/ambr/commit/b1c05b0e76989932eeb660004431de5ae5a04f15))
- Update pre-commit hooks (#126) - ([ff645ac](https://github.com/seriaati/ambr/commit/ff645ac0d9e0f406cc8794ba6e05b5beb8a5c596))
- Ensure proper path triggers - ([55a94f1](https://github.com/seriaati/ambr/commit/55a94f1eefdac84dcdd14d18329e881e48fe6489))
- Update pre-commit hooks (#129) - ([4c9d03e](https://github.com/seriaati/ambr/commit/4c9d03ef59913063cfb334f14035f6357f5c838a))

## Documentation

- Better API reference docs - ([d2d5ec4](https://github.com/seriaati/ambr/commit/d2d5ec420a51e36d1963e5463f5fa9b34fa614d8))

## Features

- Add Element.NONE to be compatible with Manekins - ([7c690f2](https://github.com/seriaati/ambr/commit/7c690f2c76ae6277c4314e3b5396627b5b391711))

## Miscellaneous Chores

- **(deps)** lock file maintenance (#119) - ([a9343f3](https://github.com/seriaati/ambr/commit/a9343f392fdf767371055209c740e5bf432b3179))
- **(deps)** lock file maintenance (#120) - ([ff7b4aa](https://github.com/seriaati/ambr/commit/ff7b4aa55b7a890d9cad0925d66a8fe47e3867ed))
- **(deps)** lock file maintenance (#121) - ([ddfa0f9](https://github.com/seriaati/ambr/commit/ddfa0f968c52e5f339a151e90aabdaddc37f707e))
- **(deps)** lock file maintenance (#122) - ([0cde4ec](https://github.com/seriaati/ambr/commit/0cde4ecad8e9b63e252ad2f2110ea348b3831c7b))
- **(deps)** update astral-sh/setup-uv action to v7 (#124) - ([0786165](https://github.com/seriaati/ambr/commit/0786165687a5381b5d9b0d0d2f42edf665a913de))
- **(deps)** lock file maintenance (#125) - ([8196853](https://github.com/seriaati/ambr/commit/8196853bc2ecc7222ee6db57f5cfd0926a6f15d7))
- **(deps)** lock file maintenance (#128) - ([6177957](https://github.com/seriaati/ambr/commit/6177957881f541517b27c87e15dfd15272659ce1))

<!-- generated by git-cliff -->
